﻿/**
 * Initializes the widget.
 *
 * This function is called when the InitScript property of
 * wisej.web.Widget changes.
 *
 * "this" refers to the container which is a wisej.web.Widget instance.
 *
 * The widget has an inner container with id = "container" that can
 * be used referring to this.container.
 *
 */
this.init = function () {

	// get the unique editor id.
	// replace - with _ to make it a valid identified when used
	// directly.
	var id = this.getId() + "_tinyeditor";

	// create the dom child.
	this.container.innerHTML = "<textarea id=\"" + id + "\"></textarea>";

	// create the tinyeditor instance using the options map generated on the server.
	var options = $options;

	options.id = id;
	options.width = "100%";
	options.height = "100%";
	options.cssclass = 'tinyeditor';
	options.controlclass = 'tinyeditor-control';
	options.rowclass = 'tinyeditor-header';
	options.dividerclass = 'tinyeditor-divider';
	options.xhtml = true;
	options.bodyid = 'editor';
	options.footerclass = 'tinyeditor-footer';
	options.toggle = { cssclass: 'toggle' };

	this.tinyEditor = new TINY.editor.edit(id, options);

	// preload the editor's images to display them in the designer.
	qx.io.ImageLoader.load("resource.wx//Wisej.Web.Ext.TinyEditor/icons.png");
	qx.io.ImageLoader.load("resource.wx/Wisej.Web.Ext.TinyEditor/header-bg.gif");

	// save the gap to calculate the new iframe size when resizing.
	var i = this.tinyEditor.i;
	var gap = i.parentNode.parentNode.offsetHeight - i.offsetHeight;
	this.tinyEditor.i.height =
		this.tinyEditor.t.style.height =
			(this.getHeight() - gap) + "px";

	// resize the tinyeditor when the widget is resized.
	this.addListener("resize", function (e) {

		this.tinyEditor.i.height =
			this.tinyEditor.t.style.height =
				(this.getHeight() - gap) + "px";

	}, this);


	// detect when the editor loses the focus to mark it as dirty and send the state back to the server.
	var editorId = this.getId();
	var savedText = this.getText();

	// hookup the blur event in the child iframe to fire onEditorBlur in the owner window.
	if (!wisej.web.DesignMode) {

		this.tinyEditor.i.contentWindow.document.body.addEventListener("blur", function () {

			var comp = window.top.Wisej.Core.getComponent(editorId);
			if (comp != null) {
				comp.onEditorBlur();
			}
		});
		this.onEditorBlur = function () {
			var newText = this.getText();
			if (savedText != newText) {
				this.setDirty(true);
				savedText = newText;
			}
		};

		// inform the server widget that the editor is ready.
		this.fireWidgetEvent("load");

		// add the text property to the state variables returned to the server with any event.
		this.setStateProperties(this.getStateProperties().concat(["text"]));
	}
}

/**
 * Text property.
 *
 * Returns or sets the html text in the editable area.
 */
this.getText = function () {
	try {
		return this.tinyEditor.i.contentWindow.document.body.innerHTML;
	} catch (e) { }
}
this.setText = function (value) {
	try {
		this.tinyEditor.i.contentWindow.document.body.innerHTML = value;
		this.updateState();
	} catch (e) { }
}

/**
 * Executes commands to manipulate the contents of the editable region.
 *
 * @param command {String} The name of the command to execute.
 * @param showDefaultUI {Boolean} Indicates whether the default user interface should be shown.
 * @param argument {String} For commands which require an input argument, this is it.
 */
this.execCommand = function (command, showDefaultUI, argument) {

	debugger;

	try {
		this.tinyEditor.e.execCommand(command, showDefaultUI || false, argument);
	} catch (e) { }
}